package com.cirs.biz.mapper;

import java.util.List;
import com.cirs.biz.domain.TPageViewTime;

/**
 * 页面浏览时长Mapper接口
 * 
 * @author allen
 * @date 2023-11-03
 */
public interface TPageViewTimeMapper 
{
    /**
     * 查询页面浏览时长
     * 
     * @param id 页面浏览时长主键
     * @return 页面浏览时长
     */
    public TPageViewTime selectTPageViewTimeById(Long id);

    /**
     * 查询页面浏览时长列表
     * 
     * @param tPageViewTime 页面浏览时长
     * @return 页面浏览时长集合
     */
    public List<TPageViewTime> selectTPageViewTimeList(TPageViewTime tPageViewTime);

    /**
     * 新增页面浏览时长
     * 
     * @param tPageViewTime 页面浏览时长
     * @return 结果
     */
    public int insertTPageViewTime(TPageViewTime tPageViewTime);

    /**
     * 修改页面浏览时长
     * 
     * @param tPageViewTime 页面浏览时长
     * @return 结果
     */
    public int updateTPageViewTime(TPageViewTime tPageViewTime);

    /**
     * 删除页面浏览时长
     * 
     * @param id 页面浏览时长主键
     * @return 结果
     */
    public int deleteTPageViewTimeById(Long id);

    /**
     * 批量删除页面浏览时长
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTPageViewTimeByIds(Long[] ids);
}
